==> core-react-library-1.0.48.tgz: package/actions/core/application.js <==
import axios from 'axios';

const create = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_CORE_API}/applications`, data, Object.keys(headers).length > 0 && { headers });

        return response;
    } catch (error) {
        throw error;
    }
};

const get = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getAll = async (headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const update = async (id, data, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_CORE_API}/applications/${id}`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const remove = async (id, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_CORE_API}/applications/${id}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

const upload = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_CORE_API}/applications/upload`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const createConfig = async (id, data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getConfigs = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getConfig = async (id, key, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs/${key}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const updateConfig = async (id, key, data, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs/${key}`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const removeConfig = async (id, key, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs/${key}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

const getHistory = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}/history`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const activateVersion = async (id, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_CORE_API}/application-history/${id}/activate`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const removeVersion = async (id, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_CORE_API}/application-history/${id}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

export const ApplicationCoreService = {
    create,
    get,
    getAll,
    update,
    remove,
    upload,
    createConfig,
    getConfigs,
    getConfig,
    updateConfig,
    removeConfig,
    getHistory,
    activateVersion,
    removeVersion
};

==> core-react-library-1.0.55.tgz: package/actions/core/application.js <==
import axios from 'axios';

const create = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_CORE_API}/applications`, data, Object.keys(headers).length > 0 && { headers });

        return response;
    } catch (error) {
        throw error;
    }
};

const get = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getAll = async (headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const update = async (id, data, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_CORE_API}/applications/${id}`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const remove = async (id, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_CORE_API}/applications/${id}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

const upload = async (data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_CORE_API}/applications/upload`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const createConfig = async (id, data, headers = {}) => {
    try {
        const response = await axios.post(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getConfigs = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const getConfig = async (id, key, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs/${key}`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const updateConfig = async (id, key, data, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs/${key}`, data, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const removeConfig = async (id, key, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_CORE_API}/applications/${id}/configs/${key}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

const getHistory = async (id, headers = {}) => {
    try {
        const response = await axios.get(`${process.env.REACT_APP_CORE_API}/applications/${id}/history`, Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const activateVersion = async (id, headers = {}) => {
    try {
        const response = await axios.put(`${process.env.REACT_APP_CORE_API}/application-history/${id}/activate`, '', Object.keys(headers).length > 0 && { headers });

        return response.data;
    } catch (error) {
        throw error;
    }
};

const removeVersion = async (id, headers = {}) => {
    try {
        await axios.delete(`${process.env.REACT_APP_CORE_API}/application-history/${id}`, Object.keys(headers).length > 0 && { headers });

        return;
    } catch (error) {
        throw error;
    }
};

export const ApplicationCoreService = {
    create,
    get,
    getAll,
    update,
    remove,
    upload,
    createConfig,
    getConfigs,
    getConfig,
    updateConfig,
    removeConfig,
    getHistory,
    activateVersion,
    removeVersion
};
